@@ -78,7 +78,7 @@ func cmdLsF(p *lang.Process) (err error) {
 func cmdLsFHelp(p *lang.Process) error {
 	v := make(map[string]string)
 	for r, f := range fFlagLookup {
-		v[string([]rune{r})] = f.String()
+		v[string([]rune{r})] = cmdLsFHelpLookup(r, f)
 	}
 
 	b, err := json.Marshal(v, p.Stdout.IsTTY())
@@ -88,3 +88,23 @@ func cmdLsFHelp(p *lang.Process) error {
 	_, err = p.Stdout.Write(b)
 	return err
 }
+
+func cmdLsFHelpLookup(r rune, f fFlagsT) string {
+	switch r {
+
+	case 'f':
+		return "any file type (inc symlinks)"
+	case 'd':
+		return "directory (inc symlinks)"
+	case 'r':
+		return "user, group and other read"
+	case 'w':
+		return "user, group and other write"
+	case 'x':
+		return "user, group and other execute"
+	case '?':
+		return "deprecated -- use `i` instead"
+	default:
+		return f.String()
+	}
+}
