@@ -82,7 +82,7 @@ func init() {
 		"murex-docs":            "Displays the man pages for Murex builtins",
 		"murex-package":         "Murex's package manager",
 		"murex-parser":          "Runs the Murex parser against a block of code",
-		"murex-update-exe-list": "Forces Murex to rescan $PATH looking for exectables",
+		"murex-update-exe-list": "Forces Murex to rescan $PATH looking for executables",
 		"null":                  "null function. Similar to /dev/null",
 		"open-image":            "Renders bitmap image data on your terminal",
 		"open":                  "Open a file with a preferred handler",
@@ -191,6 +191,7 @@ func init() {
 		"event":                 "event",
 		"!event":                "event",
 		"exec":                  "exec",
+		"command":               "exec",
 		"exit":                  "exit",
 		"exitnum":               "exitnum",
 		"export":                "export",
@@ -200,6 +201,7 @@ func init() {
 		"f":                     "f",
 		"false":                 "false",
 		"fexec":                 "fexec",
+		"builtin":               "fexec",
 		"fg":                    "fg",
 		"fid-kill":              "fid-kill",
 		"fid-killall":           "fid-killall",
