@@ -26,6 +26,10 @@ func BufferRecall(_ []byte, _ string) {
 	// not supported on this platform
 }
 
+func BufferGet() {
+	// not supported on this platform
+}
+
 func ConfigRead() (interface{}, error) {
 	return false, nil
 }
@@ -33,3 +37,11 @@ func ConfigRead() (interface{}, error) {
 func ConfigWrite(_ interface{}) error {
 	return errors.New(errMessage)
 }
+
+func MissingCrLf() bool {
+	return false
+}
+
+func WriteCrLf() {
+	// empty function for cross compiling compatibility
+}
