@@ -93,10 +93,12 @@ func CacheHints() {
 	exes := allExecutables(true)
 
 	for exe := range exes {
-		hintsummary.Cache.Set(exe, hintsummary.Get(exe, true))
+		hintsummary.Get(exe, true)
 	}
 }
 
+//func CacheHints
+
 // MatchVars returns autocomplete suggestions for variables based on a partial
 // string
 func MatchVars(partial string) (items []string) {
@@ -108,7 +110,6 @@ func MatchVars(partial string) (items []string) {
 		}
 	}
 
-	//sort.Strings(items)
 	return
 }
 
