@@ -34,8 +34,18 @@ var (
 	// PromptId is an custom defined ID for each prompt Goprocess so we don't
 	// accidentally end up with multiple prompts running
 	PromptId = new(counter.MutexCounter)
+
+	// Events is a callback for onPrompt events
+	Events func(string, []rune)
 )
 
+func callEvents(interrupt string, cmdLine []rune) {
+	if Events == nil {
+		return
+	}
+	Events(interrupt, cmdLine)
+}
+
 // Start the interactive shell
 func Start() {
 	if debug.Enabled {
@@ -146,7 +156,7 @@ func ShowPrompt() {
 		if nLines > 1 {
 			prompt = getMultilinePrompt(nLines)
 		} else {
-			prePostPromptFunction("pre")
+			callEvents("before", nil)
 			block = []rune{}
 			prompt = getPrompt()
 			writeTitlebar()
@@ -164,10 +174,12 @@ func ShowPrompt() {
 				merged = ""
 				nLines = 1
 				fmt.Fprintln(tty.Stdout, PromptSIGINT)
+				callEvents("cancel", nil)
 				continue
 
 			case readline.EOF:
 				fmt.Fprintln(tty.Stdout, utils.NewLineString)
+				callEvents("eof", nil)
 				lang.Exit(0)
 
 			default:
@@ -216,8 +228,6 @@ func ShowPrompt() {
 			continue
 
 		default:
-			//tty.BufferRecall(prompt, syntaxHighlight(block))
-
 			merged += line
 			mergedExp, err := history.ExpandVariablesInLine([]rune(merged), Prompt)
 			if err == nil {
@@ -243,7 +253,7 @@ func ShowPrompt() {
 			nLines = 1
 			merged = ""
 
-			prePostPromptFunction("post")
+			callEvents("after", block)
 
 			fork := lang.ShellProcess.Fork(lang.F_PARENT_VARTABLE | lang.F_NEW_MODULE | lang.F_NO_STDIN)
 			fork.FileRef = &ref.File{Source: &ref.Source{Module: app.ShellModule}}
