@@ -77,8 +77,11 @@ const (
 	seqClearLineBefore  = "\x1b[1k"
 	seqClearLine        = "\x1b[2k"
 	seqClearScreenBelow = "\x1b[J"
+	seqClearScreen      = "\x1b[2J"
 
 	seqGetCursorPos = "\x1b6n" // response: "\x1b{Line};{Column}R"
+
+	seqSetCursorPosTopLeft = "\x1b[1;1H"
 )
 
 // Text effects
@@ -130,3 +133,63 @@ const (
 	seqBgCyanBright    = "\x1b[1;46m"
 	seqBgWhiteBright   = "\x1b[1;47m"*/
 )
+
+const (
+	seqEscape = "\x1b"
+
+	// generated using:
+	// a [a..z] -> foreach c { -> tr [:lower:] [:upper:] -> set C; out (seqAlt$C = "\x1b$c") }
+	seqAltA = "\x1ba"
+	seqAltB = "\x1bb"
+	seqAltC = "\x1bc"
+	seqAltD = "\x1bd"
+	seqAltE = "\x1be"
+	seqAltF = "\x1bf"
+	seqAltG = "\x1bg"
+	seqAltH = "\x1bh"
+	seqAltI = "\x1bi"
+	seqAltJ = "\x1bj"
+	seqAltK = "\x1bk"
+	seqAltL = "\x1bl"
+	seqAltM = "\x1bm"
+	seqAltN = "\x1bn"
+	seqAltO = "\x1bo"
+	seqAltP = "\x1bp"
+	seqAltQ = "\x1bq"
+	seqAltR = "\x1br"
+	seqAltS = "\x1bs"
+	seqAltT = "\x1bt"
+	seqAltU = "\x1bu"
+	seqAltV = "\x1bv"
+	seqAltW = "\x1bw"
+	seqAltX = "\x1bx"
+	seqAltY = "\x1by"
+	seqAltZ = "\x1bz"
+
+	seqAltShiftA = "\x1bA"
+	seqAltShiftB = "\x1bB"
+	seqAltShiftC = "\x1bC"
+	seqAltShiftD = "\x1bD"
+	seqAltShiftE = "\x1bE"
+	seqAltShiftF = "\x1bF"
+	seqAltShiftG = "\x1bG"
+	seqAltShiftH = "\x1bH"
+	seqAltShiftI = "\x1bI"
+	seqAltShiftJ = "\x1bJ"
+	seqAltShiftK = "\x1bK"
+	seqAltShiftL = "\x1bL"
+	seqAltShiftM = "\x1bM"
+	seqAltShiftN = "\x1bN"
+	seqAltShiftO = "\x1bO"
+	seqAltShiftP = "\x1bP"
+	seqAltShiftQ = "\x1bQ"
+	seqAltShiftR = "\x1bR"
+	seqAltShiftS = "\x1bS"
+	seqAltShiftT = "\x1bT"
+	seqAltShiftU = "\x1bU"
+	seqAltShiftV = "\x1bV"
+	seqAltShiftW = "\x1bW"
+	seqAltShiftX = "\x1bX"
+	seqAltShiftY = "\x1bY"
+	seqAltShiftZ = "\x1bZ"
+)
